@@ -3,6 +3,8 @@ package AI::Pathfinding::OptimizeMultiple;
 use strict;
 use warnings;
 
+use 5.012;
+
 use IO::Handle;
 
 use AI::Pathfinding::OptimizeMultiple::IterState;
@@ -14,7 +16,7 @@ use MooX qw/late/;
 
 use PDL;
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 has chosen_scans => (isa => 'ArrayRef', is => 'rw');
 has _iter_idx => (isa => 'Int', is => 'rw', default => sub { 0; },);
@@ -630,7 +632,7 @@ set of initial conditions (for better average performance).
 
 =head1 VERSION
 
-version 0.0.6
+version 0.0.7
 
 =head1 SYNOPSIS
 
@@ -921,6 +923,6 @@ from your repository :)
 
 L<http://bitbucket.org/shlomif/fc-solve>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/fc-solve
+  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
 
 =cut
