@@ -3,6 +3,8 @@ package AI::Pathfinding::OptimizeMultiple::DataInputObj;
 use strict;
 use warnings;
 
+use 5.012;
+
 use MooX qw/late/;
 
 use File::Path qw(mkpath);
@@ -12,7 +14,7 @@ use AI::Pathfinding::OptimizeMultiple::Scan;
 use PDL;
 use PDL::IO::FastRaw;
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 has start_board => (isa => 'Int', is => 'ro', required => 1);
 has num_boards => (isa => 'Int', is => 'ro', required => 1);
@@ -390,7 +392,7 @@ AI::Pathfinding::OptimizeMultiple::DataInputObj - handle the data input.
 
 =head1 VERSION
 
-version 0.0.6
+version 0.0.7
 
 =head1 SUBROUTINES/METHODS
 
@@ -586,6 +588,6 @@ from your repository :)
 
 L<http://bitbucket.org/shlomif/fc-solve>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/fc-solve
+  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
 
 =cut
