@@ -3,11 +3,13 @@ package AI::Pathfinding::OptimizeMultiple::IterState;
 use strict;
 use warnings;
 
+use 5.012;
+
 use MooX qw/late/;
 
 use PDL ();
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 use vars (qw(@fields));
 
@@ -176,7 +178,7 @@ AI::Pathfinding::OptimizeMultiple::IterState - iteration state object.
 
 =head1 VERSION
 
-version 0.0.6
+version 0.0.7
 
 =head1 SUBROUTINES/METHODS
 
@@ -368,6 +370,6 @@ from your repository :)
 
 L<http://bitbucket.org/shlomif/fc-solve>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/fc-solve
+  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
 
 =cut
